# Set the different path for this activity
# This is sourced by runit.sh
path=$1
activity=money
plugindir=$path/.libs
pythonplugindir=$path 
resourcedir=$path/resources
section="/math/numeration/money_group"
